@@ -63,6 +63,17 @@ assert_position <- function(position, arg = caller_arg(position),
     }
 }
 
+assert_guides <- function(guides, arg = caller_arg(guides),
+                          call = caller_call()) {
+    assert_string(guides, empty_ok = FALSE, arg = arg, call = call)
+    if (grepl("[^tlbri]", guides)) {
+        cli_abort(sprintf(
+            "{.arg {arg}} can only contain the %s characters",
+            oxford_and(c(.tlbr, "i"))
+        ), call = call)
+    }
+}
+
 assert_layout_position <- function(position, arg = caller_arg(position),
                                    call = caller_call()) {
     if (!is.waive(position) && !is.null(position)) {
@@ -70,6 +81,13 @@ assert_layout_position <- function(position, arg = caller_arg(position),
     }
 }
 
+assert_layout_guides <- function(guides, arg = caller_arg(guides),
+                                 call = caller_call()) {
+    if (!is.waive(guides) && !is.null(guides)) {
+        assert_guides(guides, arg = arg, call = call)
+    }
+}
+
 #' @importFrom grid is.unit
 check_stack_sizes <- function(sizes, arg = caller_arg(sizes),
                               call = caller_call()) {
